@@ -4,17 +4,17 @@ class __ValidPrintResult:
 
     def __call__(self, print_result) -> bool:
         """
-        Validates that the `print_result` parameter is a boolean.
+        Validates that the input is a boolean value.
 
         Parameters
         ----------
         print_result : Any
-            The value to validate as a boolean.
+            The value to be validated as a boolean.
 
         Returns
         -------
         bool
-            The validated boolean value of `print_result`.
+            The validated boolean value.
 
         Raises
         ------
